@@ -1,3 +1,5 @@
+#![cfg_attr(io_lifetimes_use_std, feature(io_safety))]
+
 mod dir;
 mod file;
 pub mod sched;
@@ -108,5 +110,7 @@ where
     Fut: Future<Output = Result<T, Error>>,
     T: Send + 'static,
 {
-    tokio::task::block_in_place(move || wiggle::run_in_dummy_executor(f()))
+    tokio::task::block_in_place(move || {
+        wiggle::run_in_dummy_executor(f()).expect("wrapped operation should be synchronous")
+    })
 }
